@@ -123,7 +123,7 @@ class TabSqliteDbTestCase(unittest.TestCase):
                 for i in range(1, len(token)):
                     candidates = self.database.select_words(
                         token[:i], p_phrase=p_token, pp_phrase=pp_token)
-                    if candidates and candidates[0][0] == token:
+                    if candidates and candidates[0].phrase == token:
                         length_typed = i
                         break
                     if i == len(token) - 1:
@@ -175,11 +175,11 @@ class TabSqliteDbTestCase(unittest.TestCase):
         self.init_database(
             user_db_file=':memory:', dictionary_names=['en_US'])
         print(self.database.select_words(
-            'baltim', p_phrase='foo', pp_phrase='bar')[0][0])
+            'baltim', p_phrase='foo', pp_phrase='bar')[0].phrase)
         self.assertEqual(
             'Baltimore',
             self.database.select_words(
-                'baltim', p_phrase='foo', pp_phrase='bar')[0][0])
+                'baltim', p_phrase='foo', pp_phrase='bar')[0].phrase)
 
     @unittest.skipUnless(
         itb_util.get_hunspell_dictionary_wordlist('en_US')[0],
@@ -255,12 +255,12 @@ class TabSqliteDbTestCase(unittest.TestCase):
         self.database.hunspell_obj.set_dictionary_names(['en_US'])
         stats = self.simulate_typing_file(training_file, verbose=False)
         LOGGER.info('stats=%s', repr(stats))
-        # -9.3% saved when typing the English poem with the en_US dictionary:
-        self.assertEqual(-9.3, round(stats['percent'], 1))
+        # -9.8% saved when typing the English poem with the en_US dictionary:
+        self.assertEqual(-9.8, round(stats['percent'], 1))
         self.assertEqual(
             'undergrad',
             self.database.select_words(
-                'undergr', p_phrase='in', pp_phrase='the')[0][0])
+                'undergr', p_phrase='in', pp_phrase='the')[0].phrase)
         self.assertEqual(0, self.database.number_of_rows_in_database())
         self.assertEqual(
             True, self.read_training_data_from_file(training_file))
@@ -271,7 +271,7 @@ class TabSqliteDbTestCase(unittest.TestCase):
         self.assertEqual(
             'undergrowth',
             self.database.select_words(
-                'undergr', p_phrase='in', pp_phrase='the')[0][0])
+                'undergr', p_phrase='in', pp_phrase='the')[0].phrase)
         stats = self.simulate_typing_file(training_file, verbose=False)
         LOGGER.info('stats=%s', repr(stats))
         # -51.3% saved when typing the English poem with the trained database
@@ -316,11 +316,13 @@ class TabSqliteDbTestCase(unittest.TestCase):
         # -7.3% saved on Fedora 35 when typing the French poem with
         # the fr_FR dictionary. On openSUSE Tumbleweed (2021-11-23)
         # it is -8.2%.
-        self.assertEqual(-7.3, round(stats['percent'], 1))
+        # -9.0% on Fedora 42 when the results from select_words()
+        # are normalized to NFC.
+        self.assertEqual(-9.0, round(stats['percent'], 1))
         self.assertEqual(
             'plonge',
             self.database.select_words(
-                'plong', p_phrase='nous', pp_phrase='Bientôt')[0][0])
+                'plong', p_phrase='nous', pp_phrase='Bientôt')[0].phrase)
         self.assertEqual(0, self.database.number_of_rows_in_database())
         self.assertEqual(
             True, self.read_training_data_from_file(training_file))
@@ -331,20 +333,24 @@ class TabSqliteDbTestCase(unittest.TestCase):
         self.assertEqual(
             'plongerons',
             self.database.select_words(
-                'plong', p_phrase='nous', pp_phrase='Bientôt')[0][0])
+                'plong', p_phrase='nous', pp_phrase='Bientôt')[0].phrase)
         stats = self.simulate_typing_file(training_file, verbose=False)
         LOGGER.info('stats=%s', repr(stats))
         # -37.6% saved when typing the French poem with the trained database
         # and the fr_FR dictionary:
-        self.assertEqual(-37.6, round(stats['percent'], 1))
-        # Set the fr_FR dictionary and see whether that makes the result worse:
+        # -50.0% saved when the results from select_words()
+        # are normalized to NFC.
+        self.assertEqual(-50.0, round(stats['percent'], 1))
+        # Set the en_US dictionary and see whether that makes the result worse:
         self.database.hunspell_obj.set_dictionary_names(['en_US'])
         stats = self.simulate_typing_file(training_file, verbose=False)
         LOGGER.info('stats=%s', repr(stats))
         # -37.6% saved when typing the French poem with the trained database
         # and the en_US dictionary. When the database is trained so well,
         # the dictionary almost doesn’t matter anymore:
-        self.assertEqual(-37.6, round(stats['percent'], 1))
+        # -50.0% saved when the results from select_words()
+        # are normalized to NFC.
+        self.assertEqual(-50.0, round(stats['percent'], 1))
 
     @unittest.skipUnless(
         itb_util.get_hunspell_dictionary_wordlist('fr_FR')[0],
